@@ -14,7 +14,6 @@
 #include <libxml/xmlIO.h>
 #include <libxml/entities.h>
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -319,6 +318,7 @@ struct _xmlSAXHandler {
     getParameterEntitySAXFunc getParameterEntity;
     cdataBlockSAXFunc cdataBlock;
     externalSubsetSAXFunc externalSubset;
+    int initialized;
 };
 
 /**
@@ -576,5 +576,7 @@ xmlParserInputPtr
 }
 #endif
 
+#include <libxml/globals.h>
+
 #endif /* __XML_PARSER_H__ */
 
