@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * $Id: strio.c,v 1.3 2001/04/21 16:57:25 breese Exp $
+ * $Id: strio.c,v 1.4 2001/06/05 12:46:33 breese Exp $
  *
  * Copyright (C) 1998 Bjorn Reese and Daniel Stenberg.
  *
@@ -20,9 +20,9 @@
  * - StrToLongDouble
  */
  
-static const char rcsid[] = "@(#)$Id: strio.c,v 1.3 2001/04/21 16:57:25 breese Exp $";
+static const char rcsid[] = "@(#)$Id: strio.c,v 1.4 2001/06/05 12:46:33 breese Exp $";
 
-#if defined(unix) || defined(__xlC__)
+#if defined(unix) || defined(__xlC__) || defined(__QNX__)
 # define PLATFORM_UNIX
 #elif defined(WIN32) || defined(_WIN32)
 # define PLATFORM_WIN32
@@ -36,6 +36,7 @@ static const char rcsid[] = "@(#)$Id: strio.c,v 1.3 2001/04/21 16:57:25 breese E
 
 #include "strio.h"
 #include <string.h>
+#include <locale.h>
 #include <ctype.h>
 #include <stdarg.h>
 #include <time.h>
@@ -61,8 +62,13 @@ static const char rcsid[] = "@(#)$Id: strio.c,v 1.3 2001/04/21 16:57:25 breese E
 # define USE_STRCASECMP
 # define USE_STRNCASECMP
 # define USE_STRERROR
+# if defined(__QNX__)
+#  define strcasecmp(x,y) stricmp(x,y)
+#  define strncasecmp(x,y,n) strnicmp(x,y,n)
+# endif
 #elif defined(PLATFORM_WIN32)
-# define USE_STRCMPI
+# define USE_STRCASECMP
+# define strcasecmp(x,y) strcmpi(x,y)
 #endif
 
 /*************************************************************************
@@ -101,7 +107,7 @@ char *StrDuplicate(const char *source)
 
   assert(VALID(source));
 
-  target = (char *)malloc(StrLength(source) + 1);
+  target = StrAlloc(StrLength(source) + 1);
   if (target)
     {
       StrCopy(target, source);
@@ -126,7 +132,7 @@ char *StrDuplicateMax(const char *source, size_t max)
     {
       len = max;
     }
-  target = (char *)malloc(len);
+  target = StrAlloc(len);
   if (target)
     {
       StrCopyMax(target, len, source);
@@ -146,8 +152,6 @@ int StrEqual(const char *first, const char *second)
     {
 #if defined(USE_STRCASECMP)
       return (0 == strcasecmp(first, second));
-#elif defined(USE_STRCMPI)
-      return (0 == strcmpi(first, second));
 #else
       while ((*first != NIL) && (*second != NIL))
 	{
@@ -194,6 +198,21 @@ int StrEqualCaseMax(const char *first, size_t max, const char *second)
   return FALSE;
 }
 
+/*************************************************************************
+ * StrEqualLocale
+ */
+int StrEqualLocale(const char *first, const char *second)
+{
+  assert(VALID(first));
+  assert(VALID(second));
+
+#if defined(LC_COLLATE)
+  return (strcoll(first, second) == 0);
+#else
+  return StrEqual(first, second);
+#endif
+}
+
 /*************************************************************************
  * StrEqualMax
  */
@@ -293,7 +312,7 @@ int StrMatch(char *string, char *pattern)
 	{
 	  return (NIL == *pattern);
 	}
-      if ((toupper(*string) != toupper(*pattern))
+      if ((toupper((int)*string) != toupper((int)*pattern))
 	  && ('?' != *pattern))
 	{
 	  return FALSE;
@@ -435,9 +454,9 @@ double StrToDouble(const char *source, const char **endp)
       while (isxdigit((int)*source))
 	{
 	  integer *= 16;
-	  integer += (isdigit((int)*source) ? (*source - '0') :
-	    (isupper((int)*source) ? (*source - 'A') :
-	     (*source - 'a')));
+	  integer += (isdigit((int)*source)
+		      ? (*source - '0')
+		      : 10 + (toupper((int)*source) - 'A'));
 	  source++;
 	}
       if (*source == '.')
@@ -446,9 +465,9 @@ double StrToDouble(const char *source, const char **endp)
 	  while (isxdigit((int)*source))
 	    {
 	      fraction *= 16;
-	      fraction += (isdigit((int)*source) ? (*source - '0') :
-			   (isupper((int)*source) ? (*source - 'A') :
-			    (*source - 'a')));
+	      fraction += (isdigit((int)*source)
+			   ? (*source - '0')
+			   : 10 + (toupper((int)*source) - 'A'));
 	      fracdiv *= 16;
 	      source++;
 	    }
@@ -554,7 +573,7 @@ int StrToUpper(char *target)
   
   while (NIL != *target)
     {
-      *target = toupper(*target);
+      *target = toupper((int)*target);
       target++;
       i++;
     }
