@@ -73,6 +73,7 @@
 #ifdef LIBXML_CATALOG_ENABLED
 #include <libxml/catalog.h>
 #endif
+#include <libxml/globals.h>
 
 #ifdef VMS
 #define xmlRegisterDefaultInputCallbacks xmlRegisterDefInputCallbacks
@@ -121,6 +122,56 @@ static xmlOutputCallback xmlOutputCallbackTable[MAX_OUTPUT_CALLBACK];
 static int xmlOutputCallbackNr = 0;
 static int xmlOutputCallbackInitialized = 0;
 
+/**
+ * xmlCleanupInputCallbacks:
+ *
+ * clears the entire input callback table. this includes the
+ * compiled-in I/O. 
+ */
+void
+xmlCleanupInputCallbacks(void)
+{
+    int i;
+
+    if (!xmlInputCallbackInitialized)
+        return;
+
+    for (i = xmlInputCallbackNr - 1; i <= 0; i--) {
+        xmlInputCallbackTable[i].matchcallback = NULL;
+        xmlInputCallbackTable[i].opencallback = NULL;
+        xmlInputCallbackTable[i].readcallback = NULL;
+        xmlInputCallbackTable[i].closecallback = NULL;
+    }
+
+    xmlInputCallbackNr = 0;
+    xmlInputCallbackInitialized = 0;
+}
+
+/**
+ * xmlCleanupOutputCallbacks:
+ *
+ * clears the entire output callback table. this includes the
+ * compiled-in I/O callbacks. 
+ */
+void
+xmlCleanupOutputCallbacks(void)
+{
+    int i;
+
+    if (!xmlOutputCallbackInitialized)
+        return;
+
+    for (i = xmlOutputCallbackNr - 1; i <= 0; i--) {
+        xmlOutputCallbackTable[i].matchcallback = NULL;
+        xmlOutputCallbackTable[i].opencallback = NULL;
+        xmlOutputCallbackTable[i].writecallback = NULL;
+        xmlOutputCallbackTable[i].closecallback = NULL;
+    }
+
+    xmlOutputCallbackNr = 0;
+    xmlOutputCallbackInitialized = 0;
+}
+
 /************************************************************************
  *									*
  *		Standard I/O for file accesses				*
@@ -341,6 +392,13 @@ xmlFileWrite (void * context, const char * buffer, int len) {
  */
 static int
 xmlFileClose (void * context) {
+    FILE *fil;
+
+    fil = (FILE *) context;
+    if (fil == stdin)
+	return(0);
+    if (fil == stdout)
+	return(0);
     return ( ( fclose((FILE *) context) == EOF ) ? -1 : 0 );
 }
 
@@ -389,7 +447,7 @@ xmlGzfileOpen (const char *filename) {
     gzFile fd;
 
     if (!strcmp(filename, "-")) {
-        fd = gzdopen(fileno(stdin), "rb");
+        fd = gzdopen(dup(0), "rb");
 	return((void *) fd);
     }
 
@@ -431,7 +489,7 @@ xmlGzfileOpenW (const char *filename, int compression) {
 
     sprintf(mode, "wb%d", compression);
     if (!strcmp(filename, "-")) {
-        fd = gzdopen(1, mode);
+        fd = gzdopen(dup(1), mode);
 	return((void *) fd);
     }
 
