@@ -27,6 +27,7 @@
 #include <libxml/uri.h>
 #include <libxml/catalog.h>
 #include <libxml/parser.h>
+#include <libxml/globals.h>
 
 static int shell = 0;
 static int sgml = 0;
@@ -370,9 +371,11 @@ int main(int argc, char **argv) {
 	} else if (argv[i][0] == '-')
 	    continue;
 	filename = argv[i];
+	/* !!!!!!!!!!!!!!!!!!  TODO !!!!
 	if (sgml)
 	    ret = xmlLoadSGMLSuperCatalog(argv[i]);
 	else
+	   !!!!!!!!! */
 	    ret = xmlLoadCatalog(argv[i]);
 	if ((!sgml) && (ret < 0) && (create)) {
 	    xmlCatalogAdd(BAD_CAST "catalog", BAD_CAST argv[i], NULL);
