@@ -26,6 +26,7 @@
 
 
 #include <libxml/xmlmemory.h>
+#include <libxml/globals.h>
 #include <libxml/xmlerror.h>
 
 void xmlMallocBreakpoint(void);
@@ -94,9 +95,9 @@ typedef struct memnod {
 static unsigned long  debugMemSize = 0;
 static unsigned long  debugMaxMemSize = 0;
 static int block=0;
-int xmlMemStopAtBlock = 0;
-void *xmlMemTraceBlockAt = NULL;
-int xmlMemInitialized = 0;
+static int xmlMemStopAtBlock = 0;
+static void *xmlMemTraceBlockAt = NULL;
+static int xmlMemInitialized = 0;
 #ifdef MEM_LIST
 static MEMHDR *memlist = NULL;
 #endif
@@ -625,7 +626,7 @@ void debugmem_tag_error(void *p)
 #endif
 }
 
-FILE *xmlMemoryDumpFile = NULL;
+static FILE *xmlMemoryDumpFile = NULL;
 
 
 /**
@@ -657,18 +658,6 @@ xmlMemoryDump(void)
  *								*
  ****************************************************************/
 
-#if defined(DEBUG_MEMORY_LOCATION) | defined(DEBUG_MEMORY)
-xmlFreeFunc xmlFree = (xmlFreeFunc) xmlMemFree;
-xmlMallocFunc xmlMalloc = (xmlMallocFunc) xmlMemMalloc;
-xmlReallocFunc xmlRealloc = (xmlReallocFunc) xmlMemRealloc;
-xmlStrdupFunc xmlMemStrdup = (xmlStrdupFunc) xmlMemoryStrdup;
-#else
-xmlFreeFunc xmlFree = (xmlFreeFunc) free;
-xmlMallocFunc xmlMalloc = (xmlMallocFunc) malloc;
-xmlReallocFunc xmlRealloc = (xmlReallocFunc) realloc;
-xmlStrdupFunc xmlMemStrdup = (xmlStrdupFunc) strdup;
-#endif
-
 /**
  * xmlInitMemory:
  *
